ewa.rules.DefaultRule

Package ewa :: Module rules :: Class DefaultRule |
[hide private]
[frames] | no frames]

# Class DefaultRule

source code

    object --+
             |
     _jsonable --+
                 |
                DefaultRule

this may be useful as the last rule in a rule-list; it yields the filename passed and nothing else

Instance Methods | [hide private]
__call__(self, filename) | source code
Inherited from `_jsonable`: `to_jsondata` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`